Package: synlet
Type: Package
Title: Hits Selection for Synthetic Lethal RNAi Screen Data
Version: 2.12.0
Authors@R: person(given = "Chunxuan", family = "Shao", role = c("aut", "cre"), email = "chunxuan@outlook.com")
Description: Select hits from synthetic lethal RNAi screen data. For
        example, there are two identical celllines except one gene is
        knocked-down in one cellline. The interest is to find genes
        that lead to stronger lethal effect when they are knocked-down
        further by siRNA. Quality control and various visualisation
        tools are implemented. Four different algorithms could be used
        to pick up the interesting hits. This package is designed based
        on 384 wells plates, but may apply to other platforms with
        proper configuration.
License: GPL-3
biocViews: ImmunoOncology, CellBasedAssays, QualityControl,
        Preprocessing, Visualization, FeatureExtraction
Imports: data.table, ggplot2, grDevices, magrittr, methods, patchwork,
        RankProd, RColorBrewer, stats, utils
Suggests: BiocStyle, knitr, testthat, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
RoxygenNote: 7.2.3
Encoding: UTF-8
Config/pak/sysreqs: libgmp3-dev libmpfr-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:41:40 UTC
RemoteUrl: https://github.com/bioc/synlet
RemoteRef: RELEASE_3_23
RemoteSha: 3231d1e8dad1ec3b4d385261f9b5848fc9ea00df
Packaged: 2026-04-30 06:54:56 UTC; root
Author: Chunxuan Shao [aut, cre]
Maintainer: Chunxuan Shao <chunxuan@outlook.com>
Depends: R (>= 3.5.0)
Built: R 4.6.0; ; 2026-04-30 08:04:15 UTC; unix
